@@ -4,6 +4,6 @@
 #define AH_SUPPORT_5311			1
 #define AH_SUPPORT_AR5312		1
 #define AH_SUPPORT_AR5416		1
-/* #define AH_SUPPORT_AR9280		1 */
+#define AH_SUPPORT_AR9280		1
 /* #define AH_SUPPORT_WRITE_EEPROM	1 */
 /* #define AH_SUPPORT_WRITE_REGDOMAIN	1 */
