@@ -33,7 +33,7 @@
  * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
  * THE POSSIBILITY OF SUCH DAMAGES.
  *
- * $Id: wlanconfig.c 4008 2009-04-22 22:05:57Z proski $
+ * $Id: wlanconfig.c 4125 2010-03-23 22:49:56Z proski $
  */
 
 /*
@@ -66,7 +66,7 @@
  * These are taken from ieee80211_node.h
  */
 #define IEEE80211_NODE_TURBOP	0x0001		/* Turbo prime enable */
-#define IEEE80211_NODE_COMP	0x0002		/* Compresssion enable */
+#define IEEE80211_NODE_COMP	0x0002		/* Compression enable */
 #define IEEE80211_NODE_FF	0x0004          /* Fast Frame capable */
 #define IEEE80211_NODE_XR	0x0008		/* Atheros WME enable */
 #define IEEE80211_NODE_AR	0x0010		/* AR capable */
